import { Construct } from 'constructs';
import { App, TerraformStack, GcsBackend } from 'cdktf';
import { Project, GoogleProvider } from '@cdktf/provider-google';

import { AwsProvider } from '@cdktf/provider-aws';
import {
  providerConfig as googleProviderConfig,
  backendConfig,
  orgConfig,
} from './conf/gcp';

import { providerConfig as awsProviderConfig } from './conf/aws';
import { GcpNetworkingConfig } from './networking/gcp_config';
import { AwsNetworkingConfig } from './networking/aws_config';
import { GcpNetwork } from './networking/gcp';
import { AwsNetwork } from './networking/aws';

class DemoStack extends TerraformStack {
  private readonly project: Project;
  constructor(scope: Construct, name: string) {
    super(scope, name);

    new AwsProvider(this, 'demo-provider-aws', awsProviderConfig);
    new GoogleProvider(
      this,
      'main-provider-google',
      googleProviderConfig,
    );

    this.project = new Project(this, 'infra-main', orgConfig);
    new GcpNetwork(
      this,
      'demo-gcp',
      new GcpNetworkingConfig(this.project),
    );

    new AwsNetwork(this, 'demo-aws', new AwsNetworkingConfig());
  }
}

const app = new App();
const stack = new DemoStack(app, 'main');

new GcsBackend(stack, backendConfig);

app.synth();
