import { Topo, Peers, Firewall } from './types';
export type Vpcs = 'infra' | 'management' | 'sales';
export type Subnets = 'db' | 'app';

export const topo: Topo = {
  infra: {
    cidr: '10.92.0.0/16',
    subNets: {
      app: {
        cidr: '10.92.0.0/22',
        gateway: '10.92.0.1',
      },
      db: {
        cidr: '10.92.4.0/24',
        gateway: '10.92.4.1',
      },
    },
  },
  management: {
    cidr: '10.93.0.0/16',
    subNets: {
      app: {
        cidr: '10.93.0.0/22',
        gateway: '10.93.0.1',
      },
      db: {
        cidr: '10.93.4.0/24',
        gateway: '10.92.4.1',
      },
    },
  },
  sales: {
    cidr: '10.94.0.0/16',
    subNets: {
      app: {
        cidr: '10.94.0.0/22',
        gateway: '10.94.0.1',
      },
      db: {
        cidr: '10.94.4.0/24',
        gateway: '10.94.4.1',
      },
    },
  },
};

export const peers: Peers = {
  management: ['infra', 'sales'],
  infra: ['management'],
  sales: ['management'],
};

export const firewall: Firewall = {
  management: {
    ingress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
        sourceNetworks: { infra: 'app' },
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
        sourceRanges: ['0.0.0.0/0'],
      },
    ],
    egress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
      },
    ],
  },
  infra: {
    egress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
      },
    ],
    ingress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
        sourceTags: ['bar'],
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
        sourceRanges: ['0.0.0.0/0'],
      },
    ],
  },
  sales: {
    egress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
      },
    ],
    ingress: [
      {
        name: 'ping',
        allow: true,
        priority: 1000,
        protocol: 'icmp',
        sourceTags: ['foo'],
      },
      {
        name: 'catchall',
        allow: false,
        priority: 10001,
        protocol: 'all',
        sourceRanges: ['0.0.0.0/0'],
      },
    ],
  },
};
