import { topo, peers, firewall } from './config';
import {
  NetworkConfig,
  SubnetData,
  NetworkData,
  SubnetDefinition,
  NetworkDefinition,
} from './types';

import { Project } from '@cdktf/provider-google';
import { getKeys } from '../util';

interface S extends SubnetData {
  config: {
    project: string;
    ipCidrRange: string;
    gatewayAddress: string;
  };
}
interface N<S> extends NetworkData<S> {
  project: string;
}

export class GcpNetworkingConfig implements NetworkDefinition {
  topo = topo;
  peers = peers;
  firewall = firewall;
  config: NetworkConfig<S, N<S>>;

  constructor(project: Project) {
    const l = getKeys(this.topo).map((j) => {
      const subnets = this.topo[j].subNets;
      return {
        [j]: {
          project: project.name,
          subnets: getKeys(subnets)
            .map((k) => {
              return {
                [k]: {
                  config: {
                    project: project.name,
                    ipCidrRange: subnets[k].cidr,
                    gatewayAddress: subnets[k].gateway,
                  },
                },
              } as SubnetDefinition<S>;
            })
            .reduce((obj, i) => {
              return { ...obj, ...i };
            }),
        },
      } as NetworkConfig<S, N<S>>;
    });
    this.config = l.reduce((obj, i) => {
      return { ...obj, ...i };
    });
  }
}
