import { PartialRecord } from '../base';
import { Vpcs, Subnets } from './config';

type Cidr = string;
type Gateway = string;
export type SubnetConfig = { cidr: Cidr; gateway: Gateway };
type VpcAllocation = {
  cidr: string;
  subNets: Record<Subnets, SubnetConfig>;
};
export type Topo = Record<Vpcs, VpcAllocation>;
export type Peers = PartialRecord<Vpcs, Vpcs[]>;

export type Direction = 'ingress' | 'egress';

export interface SubnetData {}
export type SubnetDefinition<T extends SubnetData> = PartialRecord<
  Subnets,
  T
>;
export interface NetworkData<T> {
  subnets: SubnetDefinition<T>;
}

export type NetworkConfig<T, N extends NetworkData<T>> = Record<
  Vpcs,
  N
>;

export type Fw = {
  allow: boolean;
  name: string;
  priority: number;
  protocol: string;
  sourceTags?: string[];
  sourceRanges?: string[];
  sourceNetworks?: PartialRecord<Vpcs, Subnets>;
  port?: number;
};
type FwDefinition = { ingress: Fw[]; egress: Fw[] };
export type Firewall = Record<Vpcs, FwDefinition>;

export interface NetworkDefinition {
  readonly topo: Topo;
  readonly peers: Peers;
  readonly firewall: Firewall;
}
